OpenTelemetry SQLite3 Instrumentation
=====================================

|pypi|

.. |pypi| image:: https://badge.fury.io/py/opentelemetry-instrumentation-sqlite3.svg
   :target: https://pypi.org/project/opentelemetry-instrumentation-sqlite3/

Installation
------------

::

    pip install opentelemetry-instrumentation-sqlite3


References
----------
* `OpenTelemetry SQLite3 Instrumentation <https://opentelemetry-python-contrib.readthedocs.io/en/latest/instrumentation/sqlite3/sqlite3.html>`_
* `OpenTelemetry Project <https://opentelemetry.io/>`_
* `OpenTelemetry Python Examples <https://github.com/open-telemetry/opentelemetry-python/tree/main/docs/examples>`_

